"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var assert = require("assert");
var index_1 = require("../index");
describe('transform', function () {
    it('transforms named imports', function () {
        var imp = "import 'Bar'";
        assert.equal(index_1.default(imp), "require('Bar')");
        var imp1 = "import * as Foo from 'Bar'";
        assert.equal(index_1.default(imp1), "const Foo = require('Bar')");
    });
    it('transforms default exports', function () {
        var exp = "export {\n      default\n    } from './lib/simple';";
        assert.equal(index_1.default(exp), "const defaultObject = require('./lib/simple');\nexports.default = defaultObject;");
    });
    it('transforms multi line imports', function () {
        var imp = "import {\n      isString,\n      isFunction,\n      assign\n    } from 'min-dash';";
        assert.equal(index_1.default(imp), "const { isString,\n      isFunction,\n      assign\n    } = require('min-dash');");
    });
    it('transforms named imports and creates proxy', function () {
        var imp = "import 'Bar'";
        assert.equal(index_1.default(imp, 'proxyPath'), "proxyPath (() => require('Bar'), 'Bar')");
        var imp1 = "import * as Foo from 'Bar'";
        assert.equal(index_1.default(imp1, 'proxyPath'), "const Foo = proxyPath (() => require('Bar'), 'Bar')");
    });
    it('transforms default imports', function () {
        var imp = "import Foo from 'Bar'";
        assert.equal(index_1.default(imp), "const Foo = require('Bar').default || require('Bar')");
        var imp1 = "import * as Foo from 'Bar'";
        assert.equal(index_1.default(imp1), "const Foo = require('Bar')");
    });
    it('transforms default imports and creates proxy', function () {
        var imp = "import Foo from 'Bar'";
        assert.equal(index_1.default(imp, 'proxyPath'), "const Foo = proxyPath (() => require('Bar'), 'Bar').default || proxyPath (() => require('Bar'), 'Bar')");
        var imp1 = "import * as Foo from 'Bar'";
        assert.equal(index_1.default(imp1, 'proxyPath'), "const Foo = proxyPath (() => require('Bar'), 'Bar')");
    });
    it('transforms named arguments', function () {
        var imp = "import { Foo, Foo1 } from 'Bar'";
        assert.equal(index_1.default(imp), "const { Foo, Foo1 } = require('Bar')");
        var imp1 = "import { Foo as Boo, Foo1 } from 'Bar'";
        assert.equal(index_1.default(imp1), "const { Foo: Boo, Foo1 } = require('Bar')");
    });
    it('transforms named arguments and creates proxy', function () {
        var imp = "import { Foo, Foo1 } from 'Bar'";
        assert.equal(index_1.default(imp, 'proxyPath'), "const { Foo, Foo1 } = proxyPath (() => require('Bar'), 'Bar')");
        var imp1 = "import { Foo as Boo, Foo1 } from 'Bar'";
        assert.equal(index_1.default(imp1, 'proxyPath'), "const { Foo: Boo, Foo1 } = proxyPath (() => require('Bar'), 'Bar')");
    });
    it('transforms default and named arguments', function () {
        var imp = "import Foo, { Foo1 } from 'Bar'";
        assert.equal(index_1.default(imp), "const Foo = require('Bar').default || require('Bar')\nconst { Foo1 } = require('Bar')");
        var imp1 = "import * as Foo { Foo1 } from 'Bar'";
        assert.equal(index_1.default(imp1), "const Foo = require('Bar')\nconst { Foo1 } = require('Bar')");
    });
    it('transforms default and named arguments and creates proxy', function () {
        var imp = "import Foo, { Foo1 } from 'Bar'";
        assert.equal(index_1.default(imp, 'proxyPath'), "const Foo = proxyPath (() => require('Bar'), 'Bar').default || proxyPath (() => require('Bar'), 'Bar')\nconst { Foo1 } = proxyPath (() => require('Bar'), 'Bar')");
        var imp1 = "import * as Foo { Foo1 } from 'Bar'";
        assert.equal(index_1.default(imp1, 'proxyPath'), "const Foo = proxyPath (() => require('Bar'), 'Bar')\nconst { Foo1 } = proxyPath (() => require('Bar'), 'Bar')");
    });
    it('transforms exports', function () {
        var imp = 'export function m()';
        assert.equal(index_1.default(imp), 'function m()\nexports.m = m;');
    });
    it('transforms multiple exports', function () {
        var imp = "export function m()\nexport const n()";
        assert.equal(index_1.default(imp), 'function m()\nconst n()\nexports.m = m;\nexports.n = n;');
    });
    it('transforms default exports', function () {
        var imp = "export default function m()\nexport const n()";
        assert.equal(index_1.default(imp), 'function m()\nconst n()\nexports.n = n;\nexports.default = m;');
    });
    it('transforms unnamed default exports', function () {
        var imp = "export default function ()";
        assert.equal(index_1.default(imp), 'function defaultFunction()\nexports.default = defaultFunction;');
        imp = "export default {";
        assert.equal(index_1.default(imp), 'const defaultObject = {\nexports.default = defaultObject;');
        imp = "export default () =>";
        assert.equal(index_1.default(imp), 'const defaultFunction = () =>\nexports.default = defaultFunction;');
    });
    it('transforms default function', function () {
        var imp = "export default function(additionalPackages, options)";
        assert.equal(index_1.default(imp), 'function defaultFunction(additionalPackages, options)\nexports.default = defaultFunction;');
    });
    it('transforms default export variables', function () {
        var imp = "export default m";
        assert.equal(index_1.default(imp), 'm\nexports.default = m;');
    });
    it('ignores commonjs exports', function () {
        var imp = "exports = module.exports = debug;\n                exports.coerce = coerce;\n                exports.humanize = require('ms');";
        var a = index_1.default(imp);
        console.log(a);
        assert.equal(index_1.default(imp), imp);
    });
});
